@@ -163,7 +163,7 @@ fn publish_crate(
     .unwrap();
 
     // sleep for a bit to let the crates.io index catch up
-    thread::sleep(Duration::from_millis(7500));
+    thread::sleep(Duration::from_secs(15));
 
     already_published.insert(current_package.to_string());
 }
